.. include:: ../README.rst
.. include:: download.rst
.. include:: read_img.rst
.. include:: img2ts.rst
.. include:: read_ts.rst

Contents
========

.. toctree::
   :maxdepth: 2

   Download <download>
   Image Reading <read_img>
   Conversion to Time Series <img2ts>
   Time Series Reading <read_img>
   License <license>
   Authors <authors>
   Changelog <changelog>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
